====
Base
====

Sub-commands to support the output components


.. autosummary::
    :nosignatures:
    :toctree: _generated/

    rompy_swan.subcomponents.base.XY
    rompy_swan.subcomponents.base.IJ
